package net.sf.basedb.clients.web.extensions.list;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;

import net.sf.basedb.clients.web.Base;
import net.sf.basedb.clients.web.formatter.LinkedItemFormatter;
import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.ItemContext;
import net.sf.basedb.core.ItemList;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.Type;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;
import net.sf.basedb.util.NameableComparator;
import net.sf.basedb.util.filter.Filter;
import net.sf.basedb.util.formatter.CollectionFormatter;
import net.sf.basedb.util.formatter.NameableFormatter;
import net.sf.basedb.util.listable.SourceItemTransformer;

/**
	Related item column that get the item lists that the parent or child
	item is a member of.

	@author nicklas
	@since 3.18
*/
public class RelatedItemListColumn 
	extends RelatedItemColumn
{

	private final ItemQuery<ItemList> listQuery;
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	RelatedItemListColumn(DbControl dc, int index, Specification spec, Filter<? super ItemList> itemListFilter, RelatedItemHelper helper)
	{
		super(dc, index, spec, helper);
		ItemContext cc = dc.getSessionControl().getCurrentContext(spec.sourceType);
		setEnumeration(Base.getItemListsEnum(dc, spec.targetType, cc.getInclude(), itemListFilter));
		setTitle(spec.generateTitle("Item list"));
		setTooltip(spec.generateTooltip("Item list"));
		setValueType(Type.INT);
		setExportFormatter(new NameableFormatter());
		if (!helper.lazy) setFormatter(new CollectionFormatter(new LinkedItemFormatter()));

		listQuery = ItemList.getQuery();
		listQuery.setIncludes(cc.getInclude());
		listQuery.join(Hql.innerJoin("members", "m"));
		listQuery.restrict(Restrictions.eq(Hql.property("memberType"), Expressions.integer(spec.targetType.getValue())));
		listQuery.restrict(Restrictions.in(Hql.alias("m"), Expressions.parameter("itemId", Type.INT)));
	}
	
	@Override
	public Object getValue(RelatedItemHelper helper, Annotatable item, SourceItemTransformer preTransform) 
	{
		Set<Annotatable> items = getRelatedItems(item, preTransform);
		if (items.size() == 0) return null;

		List<Integer> allIds = new ArrayList<>(items.size());
		for (Annotatable p : items)
		{
			allIds.add(p.getId());
		}
		
		listQuery.setParameter("itemId", allIds, Type.INT);
		Set<ItemList> itemLists = new TreeSet<>(new NameableComparator<>(false));
		itemLists.addAll(listQuery.list(helper.dc));
		return itemLists.size() == 0 ? null : itemLists;
	}

}
