/**
	$Id: StartServiceRenderer.java 8127 2023-03-09 13:54:41Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.service;

import net.sf.basedb.util.extensions.AbstractRenderer;
import net.sf.basedb.util.extensions.Extension;
import net.sf.basedb.util.extensions.logging.ExtensionsLog;
import net.sf.basedb.util.extensions.logging.ExtensionsLogger;

/**
	A renderer that starts the service of a
	{@link ServiceControllerAction}.

	@author nicklas
	@version 2.8
	@base.modified $Date: 2023-03-09 14:54:41 +0100 (Thu, 09 Mar 2023) $
*/
public class StartServiceRenderer
	extends AbstractRenderer<ServiceControllerAction>
{
	private static final org.slf4j.Logger log = 
		org.slf4j.LoggerFactory.getLogger(StartServiceRenderer.class);

	public StartServiceRenderer()
	{}
	
	/**
		Calls {@link ServiceControllerAction#start()} on the <code>service</code>.
	*/
	@Override
	public void render(ServiceControllerAction service, Extension<? extends ServiceControllerAction> ext)
	{
		log.info("Starting service: " + service);
		service.start();
		ExtensionsLogger logger = ExtensionsLog.createLogger(ext.getId());
		if (service.isRunning())
		{
			logger.info("Service started");
		}
		else
		{
			logger.error("Service failed to start");
		}
		log.info("Starting service done: " + service);
	}

}
