/*
	$Id$

	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.formatter;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.File;
import net.sf.basedb.core.Nameable;
import net.sf.basedb.util.formatter.Formatter;

/**
	Formatter implementation designed for exporting that generates output
	with best supported method depending on their type.

	* Files are exported with their path
	* Nameable items are exported with their name
	* Other items are exported with their toString() method
	
	@author nicklas
	@since 3.17
*/
public class AutoItemExportFormatter 
	implements Formatter<BasicItem>
{
	
	public AutoItemExportFormatter() 
	{}
	
	@Override
	public String format(BasicItem item) 
	{
		String result = "";
		if (item instanceof File)
		{
			result = ((File)item).getPath().toString();
		}
		else if (item instanceof Nameable)
		{
			result = ((Nameable)item).getName();
		}
		else if (item != null)
		{
			result = item.toString();
		}
		return result;
	}

	@Override
	public File parseString(String value) 
	{
		throw new UnsupportedOperationException("parseString: " + value);
	}

}
