/*
	$Id: Hidden.java 7703 2019-04-11 07:31:26Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.taglib.table;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.tagext.TagSupport;

/**
	This tag defines a hidden input element that should be included in 
	the form. It should be placed inside the {@link Table &lt;tbl:table&gt;} 
	tag.

	<p>
	<b>Syntax:</b>
	<pre>
   &lt;tbl:hidden
      name=...
      value=...
      skip=true|false
   &gt;
</pre>

	<table class="as-grid">
	<caption>Tag attributes</caption>
	<tr>
		<td><b>Attribute</b></td>
		<td><b>Default value</b></td>
		<td><b>Required</b></td>
		<td><b>Description</b></td>
	</tr>
	<tr>
		<td>name</td>
		<td>-</td>
		<td>yes</td>
		<td>
			The name of the hidden element.
		</td>
	</tr>
	<tr>
		<td>value</td>
		<td>(empty string)</td>
		<td>no</td>
		<td>
			The value of the hidden element.
		</td>
	</tr>
	<tr>
		<td>skip</td>
		<td>false</td>
		<td>no</td>
		<td>
			If hidden element should be included in the form or not.
		</td>
	</tr>
	</table>
	<p>
	The <code>&lt;tbl:hidden&gt;</code> doesn't have any subtags.

	@author Nicklas
	@version 2.0
*/
public class Hidden
	extends TagSupport
{

	/**
		
	*/
	private static final long serialVersionUID = -2708187720621346925L;

	/**
		The parent &lt;tbl:table&gt; tag.
	*/
	private Table table;
	
	/**
		The name of the element.
	*/
	private String name = null;
	
	/**
		The value of the element.
	*/
	private String value = "";
	
	/**
		If the hidden element should be included or not.
	*/
	private boolean skip = false;
	
	/*
		Taglib initialization methods
	*/
	public void setName(String name)
	{
		this.name = name;
	}
	public String getName()
	{
		return name;
	}

	public void setValue(String value)
	{
		this.value = value;
	}
	public String getValue()
	{
		return value;
	}
	
	public void setSkip(boolean skip)
	{
		this.skip = skip;
	}
	public boolean isSkip()
	{
		return skip;
	}

	/*
		Display methods
	*/
	@Override
	public int doStartTag()
		throws JspException
	{
		if (!(getParent() instanceof Table)) throw new JspTagException("Tag <tbl:navigator> must be inside a <tbl:table> tag");
		table = (Table)getParent();
		if (isSkip()) return SKIP_BODY;
		table.addHidden(getName(), getValue());
		return SKIP_BODY;
	}


}


