/**
 $Id: BioWellData.java 8171 2023-11-21 09:31:51Z nicklas $

	Copyright (C) 2008 Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.basedb.core.data;

/**
 	This class holds information about a bio well on a bio plate.

  	@author Martin
  	@version 2.10
 	@see net.sf.basedb.core.BioWell
	@see <a href="../../../../../../html/developer/api/data_api.biomaterials.html">Developer documentation: Biomaterials LIMS</a>
	@base.modified $Date: 2008-11-27 16:33:55 +0100 (Thu, 27 Nov 2008) $
	@hibernate.class table="`BioWells`" lazy="true"
 */
public class BioWellData 
	extends BasicData
	implements NoAutoUnlinkAnyToAny
{
	public BioWellData()
	{}
	
	private BioPlateData bioPlate;
	/**
		The bioplate this well belongs to.
		@see BioPlateData#getBioWells()
		@hibernate.many-to-one column="`bioplate_id`" not-null="true" outer-join="false" update="false" cascade="all"
	*/
	public BioPlateData getBioPlate()
	{
		return bioPlate;
	}
	public void setBioPlate(BioPlateData bioPlate)
	{
		this.bioPlate = bioPlate;
	}
	
	private int row;
	/**
		The row coordinate of this well.
		@hibernate.property column="`row`" type="int" not-null="true" update="false"
	*/
	public int getRow()
	{
		return row;
	}
	public void setRow(int row)
	{
		this.row = row;
	}
	
	private int column;
	/**
		The column coordinate of this well.
		@hibernate.property column="`column`" type="int" not-null="true" update="false"
	*/
	public int getColumn()
	{
		return column;
	}
	public void setColumn(int column)
	{
		this.column = column;
	}
	
	private MeasuredBioMaterialData originalBioMaterial;
	/**
		The {@link MeasuredBioMaterialData} used in this well.
		@since 2.16
		@hibernate.many-to-one column="`original_biomaterial_id`" not-null="false" outer-join="false"
	*/
	public MeasuredBioMaterialData getOriginalBioMaterial()
	{
		return originalBioMaterial;
	}
	public void setOriginalBioMaterial(MeasuredBioMaterialData originalBioMaterial)
	{
		this.originalBioMaterial = originalBioMaterial;
	}
	
	private MeasuredBioMaterialData bioMaterial;
	/**
		The {@link MeasuredBioMaterialData} used in this well.
		@hibernate.one-to-one property-ref="bioWell"
	*/
	public MeasuredBioMaterialData getBioMaterial()
	{
		return bioMaterial;
	}
	public void setBioMaterial(MeasuredBioMaterialData bioMaterial)
	{
		this.bioMaterial = bioMaterial;
	}
}
