/*
  $Id: DirectoryData.java 6468 2014-06-10 11:27:02Z nicklas $

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;


/**
	This class holds information about directories.
	
	@author enell
	@version 2.0
	@see net.sf.basedb.core.Directory
	@see <a href="../../../../../../html/developer/api/data_api.files.html">Developer documentation: Files and directories</a>
	@base.modified $Date: 2014-06-10 13:27:02 +0200 (Tue, 10 Jun 2014) $
	@hibernate.class table="`Directories`" lazy="true"
 */
public class DirectoryData
	extends CommonData
	implements SystemData
{

	/*
		From the NameableData interface
		-------------------------------------------
	*/
	/**
		Get the name of the item.
		@return A <code>String</code> with the name of the item
		@hibernate.property type="string"
		@hibernate.column name="`name`" length="255" not-null="true" index="name_idx" unique-key="Directory_uniquedirectory"
	*/
	@Override
	public String getName()
	{
		return super.getName();
	}
	// -------------------------------------------
	/*
		From the SystemData interface
		-------------------------------------------
	*/
	private String systemId;
	@Override
	public String getSystemId()
	{
		return systemId;
	}
	public void setSystemId(String systemId)
	{
		this.systemId = systemId;
	}
	// -------------------------------------------

	private DirectoryData parent;
	/**
		Get the parent directory of this directory.
		@hibernate.many-to-one outer-join="false"
		@hibernate.column name="`parent_id`" unique-key="Directory_uniquedirectory" not-null="false"
	*/
	public DirectoryData getParent()
	{
		return parent;
	}
	public void setParent(DirectoryData parent)
	{
		this.parent = parent;
	}
	
	private boolean autoCompress;
	/**
		If files that are uploaded to this directory be compressed or not.
		@since 2.5
		@hibernate.property column="`auto_compress`" type="boolean" not-null="true"
	*/
	public boolean getAutoCompress()
	{
		return autoCompress;
	}
	public void setAutoCompress(boolean autoCompress)
	{
		this.autoCompress = autoCompress;
	}	
	
	private boolean autoShare;
	/**
		If new files and subdirectories should inherit the share permission
		on this directory or not.
		@since 2.8
		@hibernate.property column="`auto_share`" type="boolean" not-null="true"
	*/
	public boolean getAutoShare()
	{
		return autoShare;
	}
	public void setAutoShare(boolean autoShare)
	{
		this.autoShare = autoShare;
	}
	
	private Set<FileData> files;
	/**
		This is the inverse end.
		@see FileData#getDirectory()
		@hibernate.set lazy="true" inverse="true" 
		@hibernate.collection-key column="`directory_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.FileData"
	*/
	Set<FileData> getFiles()
	{
		return files;
	}
	void setFiles(Set<FileData> files)
	{
		this.files = files;
	}

	private Set<DirectoryData> subdirectories;
	/**
		This is the inverse end.
		@see DirectoryData#getParent()
		@hibernate.set lazy="true" inverse="true" 
		@hibernate.collection-key column="`parent_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DirectoryData"
	*/
	Set<DirectoryData> getSubdirectories()
	{
		return subdirectories;
	}
	void setSubdirectories(Set<DirectoryData> subdirectories)
	{
		this.subdirectories = subdirectories;
	}

}
