/*
  $Id: FileSetData.java 8171 2023-11-21 09:31:51Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.HashSet;
import java.util.Set;

/**
	This class collects all files used to store data
	for an item that store data in files instead of in the
	database.
	
	@author Nicklas
	@version 2.5
	@see net.sf.basedb.core.FileSet
	@see <a href="../../../../../../html/developer/api/data_api.platforms.html">Developer documentation: Experimental platforms and item subtypes</a>
	@base.modified $Date: 2023-11-21 10:31:51 +0100 (Tue, 21 Nov 2023) $
	@hibernate.class table="`FileSets`" lazy="true"
*/
public class FileSetData
	extends BasicData
	implements NoAutoUnlinkAnyToAny
{

	private int itemType;
	/**
		Get the item type this file set is associated with.
		@hibernate.property column="`item_type`" type="int" not-null="true" update="false"
	*/
	public int getItemType()
	{
		return itemType;
	}
	public void setItemType(int itemType)
	{
		this.itemType = itemType;
	}
	
	private Set<FileSetMemberData> members;
	/**
		The members of this file set. This is the inverse end.
		@see FileSetMemberData#getFileSet()
		@hibernate.set lazy="true" cascade="delete" inverse="true"
		@hibernate.collection-key column="`fileset_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.FileSetMemberData"
		@since 3.0 (was returning a Map in BASE 2.x)
	*/
	public Set<FileSetMemberData> getMembers()
	{
		if (members == null)
		{
			members = new HashSet<FileSetMemberData>();
		}
		return members;
	}
	void setMembers(Set<FileSetMemberData> members)
	{
		this.members = members;
	}

}
