/*
	$Id: PhysicalBioAssayData.java 6132 2012-09-14 10:29:16Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class holds information about a physical bioassay (eg. a hybridization or similar).
	
	@author Nicklas
	@since 3.0
	@see net.sf.basedb.core.PhysicalBioAssay
	@base.modified $Date: 2012-09-14 12:29:16 +0200 (Fri, 14 Sep 2012) $
	@hibernate.class table="`PhysicalBioAssays`" lazy="true"
	@see <a href="../../../../../../html/developer/api/data_api.bioassays.html">Developer documentation: Bioassays and raw data</a>
*/
public class PhysicalBioAssayData 
	extends AnnotatedData
	implements SubtypableData
{

	public PhysicalBioAssayData()
	{}

	/*
		From the SubtypableData interface
		----------------------------------
	*/
	private ItemSubtypeData subtype;
	@Override
	public ItemSubtypeData getItemSubtype()
	{
	   return subtype;
	}
	@Override
	public void setItemSubtype(ItemSubtypeData subtype)
	{
	   this.subtype = subtype;
	}
	// ------------------------------

	private ArraySlideData arraySlide;

	/**
		Get the array slide.
		@hibernate.many-to-one column="`arrayslide_id`" not-null="false" unique="true" outer-join="false"
	*/
	public ArraySlideData getArraySlide()
	{
		return arraySlide;
	}

	public void setArraySlide(ArraySlideData arraySlide)
	{
		this.arraySlide = arraySlide;
	}
	
	private BioMaterialEventData creationEvent;
	/**
		Get the event that created this bioassay. Mapping is defined
		in hibernate-properties-PhysicalBioassayData.xml since XDoclet 
		cannot generate it.
	*/
	public BioMaterialEventData getCreationEvent()
	{
		return creationEvent;
	}
	void setCreationEvent(BioMaterialEventData creationEvent)
	{
		this.creationEvent = creationEvent;
	}
	
	private int size;
	/**
		The number size of the bioassay. Eg. the number of biomaterial positions that
		it has. A single position may or may not hold more than one biomaterial.
		@hibernate.property column="`size`" type="int" not-null="true"
	*/
	public int getSize()
	{
		return size;
	}
	public void setSize(int size)
	{
		this.size = size;
	}

	
	private Set<DerivedBioAssayData> rootDerivedBioAssays;
	/**
		This is the inverse end with an extra restriction 
		@see DerivedBioAssayData#getPhysicalBioAssays()
		@hibernate.set table="`ParentPhysicalBioAssays`" lazy="true" inverse="true" 
		@hibernate.collection-key column="`physicalbioassay_id`"
		@hibernate.collection-many-to-many column="`derivedbioassay_id`" class="net.sf.basedb.core.data.DerivedBioAssayData" where="`is_root`"
	*/
	Set<DerivedBioAssayData> getRootDerivedBioAssays()
	{
		return rootDerivedBioAssays;
	}
	void setRootDerivedBioAssays(Set<DerivedBioAssayData> rootDerivedBioAssays)
	{
		this.rootDerivedBioAssays = rootDerivedBioAssays;
	}
	
	private Set<DerivedBioAssayData> derivedBioAssays;
	/**
		This is the inverse end.
		@see DerivedBioAssayData#getPhysicalBioAssays()
		@hibernate.set table="`ParentPhysicalBioAssays`" lazy="true" inverse="true" 
		@hibernate.collection-key column="`physicalbioassay_id`"
		@hibernate.collection-many-to-many column="`derivedbioassay_id`" class="net.sf.basedb.core.data.DerivedBioAssayData"
	*/
	Set<DerivedBioAssayData> getDerivedBioAssays()
	{
		return derivedBioAssays;
	}
	void setDerivedBioAssays(Set<DerivedBioAssayData> derivedBioAssays)
	{
		this.derivedBioAssays = derivedBioAssays;
	}

	
}
