/*
	$Id: PlateTypeData.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.Set;

/**
	This class holds information about a plate type.

	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.PlateType
	@see <a href="../../../../../../html/developer/api/data_api.plates.html">Developer documentation: Array LIMS (plates)</a>
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (Fri, 14 Sep 2012) $
	@hibernate.class table="`PlateTypes`" lazy="false"
*/
public class PlateTypeData
	extends CommonData
	implements RegisteredData
{

	public PlateTypeData()
	{}

	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	@Override
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------
	
	private PlateGeometryData plateGeometry;
	/**
		The geometry of this plate type.
		@hibernate.many-to-one column="`plategeometry_id`" not-null="true" outer-join="false" update="false"
	*/
	public PlateGeometryData getPlateGeometry()
	{
		return plateGeometry;
	}
	public void setPlateGeometry(PlateGeometryData plateGeometry)
	{
		this.plateGeometry = plateGeometry;
	}
	
	private Set<PlateEventTypeData> eventTypes;
	/**
		The event types defined for this plate type. Plates of this type can have
		events of the corresponding event type. This is the inverse end.
		@see PlateEventTypeData#getPlateType()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`platetype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.PlateEventTypeData"
	*/
	Set<PlateEventTypeData> getEventTypes()
	{
		return eventTypes;
	}
	void setEventTypes(Set<PlateEventTypeData> eventTypes)
	{
		this.eventTypes = eventTypes;
	}

	private Set<PlateData> plates;
	/**
		The plates of this type. This is the inverse end.
		@see PlateData#getPlateType()
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`platetype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.PlateData"
	*/
	Set<PlateData> getPlates()
	{
		return plates;
	}
	void setPlates(Set<PlateData> plates)
	{
		this.plates = plates;
	}

}
