/*
	$Id: ReporterTypeData.java 7015 2015-11-17 12:57:57Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.Set;

/**
	This class holds reporter type information. A reporter may have,
	but is not required to have a type. The main reason for a
	reporter to have a type is to make it easier for client
	application to filter the reporter list.

	@author Nicklas, Samuel
	@version 2.0
	@see net.sf.basedb.core.data.ReporterData
	@see <a href="../../../../../../html/developer/api/data_api.reporters.html">Developer documentation: Reporters</a>
	@hibernate.class table="`ReporterTypes`" lazy="true"
*/
public class ReporterTypeData
	extends BasicData
	implements NameableData, RemovableData, RegisteredData
{
	/**
		Default constructor.
	*/
	public ReporterTypeData()
	{}

	/*
		From the NameableData interface
		-------------------------------------------
	*/
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	@Override
	public void setName(String name)
	{
		this.name = name;
	}
	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------
	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private Integer removedBy;
	@Override
	public Integer getRemovedBy()
	{
		return removedBy;
	}
	@Override
	public void setRemovedBy(Integer removedBy)
	{
		this.removedBy = removedBy;
	}
	// -------------------------------------------
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	@Override
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	/**
		The reporters that have this type.
	*/
	private Set<ReporterData> reporter;
	/**
		This is the inverse end.
		Get reporters.
		@return A set of {@link ReporterData}.
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`reportertype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.ReporterData"
	*/
	Set<ReporterData> getReporters()
	{
		return reporter;
	}
	/**
		This is the inverse end.
		Set reporters.
		@param reporter A set of {@link ReporterData}.
	*/
	void setReporters(Set<ReporterData> reporter)
	{
		this.reporter = reporter;
	}
}
