/**
	$Id$

	Copyright (C) 2023 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.logging;

import java.util.Date;

import net.sf.basedb.core.DateUtil;
import net.sf.basedb.util.error.ThrowableUtil;

/**
	An entry in the log.
*/
public class LogEntry
{
	private final long timestamp;
	private final LogLevel level;
	private final String message;
	private final Throwable t;
	
	LogEntry(LogLevel level, String message, Throwable t)
	{
		this.timestamp = System.currentTimeMillis();
		this.level = level;
		this.message = message;
		this.t = t;
	}
	
	/**
		The level of the log entry.
	*/
	public LogLevel getLevel()
	{
		return level;
	}
	
	/**
		The timestamp of the log entry.
	*/
	public long getTimestamp()
	{
		return timestamp;
	}
	
	/**
		The timestamp of the log entry as a date.
	*/
	public Date getDate()
	{
		return new Date(timestamp);
	}
	
	/**
		Get the log message.
	*/
	public String getMessage()
	{
		return message;
	}
	
	/**
		Get the stacktrace of the log entry.
	*/
	public Throwable getStacktrace()
	{
		return t;
	}

	@Override
	public String toString() 
	{
		String s = "["+level.name()+"] ["+DateUtil.formatTimestamp(getDate())+"] "+message;
		if (t != null)
		{
			s+="\n"+ThrowableUtil.stackTraceToString(t);
		}
		return s;
	}
	
}