/**
	$Id $

	Copyright (C) 2019 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.formatter;

import java.text.NumberFormat;
import java.text.ParseException;

import net.sf.basedb.util.excel.ExcelFormatter;
import net.sf.basedb.util.excel.ExcelValue;

/**
 	Formatter implementation for numeric values that simply wrap a
 	NumberFormat instance.
 	
	@author nicklas
	@since 3.15
*/
public class NumberFormatFormatter
	implements Formatter<Number>, ExcelFormatter<Number, Number>
{

	private final NumberFormat format;
	
	/**
		Create a new number formatter.
	*/
	public NumberFormatFormatter(NumberFormat format)
	{
		this.format = format;
	}
	
	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(Number value)
	{
		return value == null ? "" : format.format(value);
	}
	@Override
	public Number parseString(String value)
	{
		if (value == null) return null;
		try
		{
			return format.parse(value);
		}
		catch (ParseException ex)
		{
			throw new NumberFormatException("For input string: \"" + value + "\"");
		}
	}
	// -------------------------------------------

	@Override
	public ExcelValue<Number> toExcelValue(Number value) 
	{
		return ExcelValue.asNumber(value, null);
	}

}
