/**
	$Id: ToStringFormatter.java 7650 2019-03-14 08:31:57Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.formatter;

import net.sf.basedb.util.excel.ExcelFormatter;
import net.sf.basedb.util.excel.ExcelValue;

/**
 	A generic formatter that simply formats objects by calling the
 	toString() method. Null values are converted to the empty string.
 	
	@author nicklas
	@version 2.0
	@base.modified $Date: 2019-03-14 09:31:57 +0100 (Thu, 14 Mar 2019) $
*/
public class ToStringFormatter<T>
	implements Formatter<T>, ExcelFormatter<T, String>
{

	/**
		Create a new integer formatter.
	*/
	public ToStringFormatter()
	{}
	
	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(T value)
	{
		return value == null ? "" : value.toString();
	}
	@Override
	public T parseString(String value)
	{
		throw new UnsupportedOperationException("parseString");
	}
	// -------------------------------------------

	/**
		@since 3.15
	*/
	@Override
	public ExcelValue<String> toExcelValue(T value) 
	{
		return value == null ? ExcelValue.emptyCell() : ExcelValue.asString(format(value));
	}

}
