/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.HashSet;
import java.util.Set;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.DerivedBioAssay;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;

/**
	Source item transformer implementation that transform derived bioassay items 
	to parent derived bioassays.
	
	@author Nicklas
	@since 3.5
*/
public class DerivedBioAssayToParentDerivedBioAssayTransformer 
	extends AbstractSourceItemTransformer
{
	
	private final boolean includeSourcesInTarget;

	/**
		Create a new derived bioassay to parent derived bioassay transformer.
	*/
	public DerivedBioAssayToParentDerivedBioAssayTransformer(boolean includeSourcesInTarget) 
	{
		super(Item.DERIVEDBIOASSAY, Item.DERIVEDBIOASSAY);
		this.includeSourcesInTarget = includeSourcesInTarget;
	}
	
	@Override
	public Set<Integer> transform(TransformContext context, Set<Integer> source) 
	{
		DbControl dc = context.getDbControl();
		
		ItemQuery<DerivedBioAssay> query = DerivedBioAssay.getQuery();
		query.setIncludes(context.getInclude());
		query.joinPermanent(Hql.innerJoin("children", "c"));
		query.restrict(
			Restrictions.in(
				Hql.alias("c"),
				Expressions.parameter("children")
			)
		);
		
		// Keep track of all seen children and parents
		Set<Integer> allParents = new HashSet<Integer>();
		Set<Integer> allChildren = new HashSet<Integer>();
		if (includeSourcesInTarget) allParents.addAll(source);

		// Children that we have not yet checked
		Set<Integer> children = source;
		while (children.size() > 0)
		{
			context.collect(getSourceItemType(), children);
			Set<Integer> parents = context.avoid(getTargetItemType(), safeIdList(dc, query, "children", children));
			
			// Store new parents and "used" children
			allParents.addAll(parents);
			allChildren.addAll(children);
			
			// Remove children that we have already seen...
			// ...the remaining parents become our new children
			parents.removeAll(allChildren);
			children = parents;
		}
		
		return allParents;
	}

}
