/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.Set;

import net.sf.basedb.core.Extract;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;

/**
	Source item transformer that transform sample items to their child
	extract. This implementation will only transform to the sample:s immediate
	child extracts. Grandchildren are not included. To do this, combine this
	transformer with a {@link SampleToChildSampleTransformer} and 
	{@link ExtractToChildExtractTransformer}.
	
	@author Nicklas
	@since 3.5
*/
public class SampleToExtractTransformer 
	extends AbstractSourceItemTransformer 
{

	public SampleToExtractTransformer()
	{
		super(Item.SAMPLE, Item.EXTRACT);
	}
	
	/**
		Load the ID of all extracts that are immediate children to the
		given set of samples.
	*/
	@Override
	public Set<Integer> transform(TransformContext context, Set<Integer> source) 
	{
		context.collect(getSourceItemType(), source);
		ItemQuery<Extract> query = Extract.getQuery();
		query.setIncludes(context.getInclude());
		// Extracts with a sample as parent
		query.restrict(Restrictions.eq(Hql.property("parentType"), Expressions.integer(Item.SAMPLE.getValue())));
		query.restrict(
			Restrictions.in(
				Hql.property("parent"), 
				Expressions.parameter("samples")
			));
		return context.avoid(getTargetItemType(), safeIdList(context.getDbControl(), query, "samples", source));
	}


}
