/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.ArrayList;
import java.util.List;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.SyncFilter.SourceItemTransform;

/**
	Transformer factory implementation for transforming to biosources. The current
	implementation support transforming from:
	
	<ul>
	<li>{@link SourceItemTransform#PARENT_TO_CHILD}: None
	<li>{@link SourceItemTransform#CHILD_TO_PARENT}: SAMPLE, EXTRACT, PHYSICALBIOASSAY, DERIVEDBIOASSAY, RAWBIOASSAY
	</ul>

	@author Nicklas
	@since 3.5
*/
public class ToBioSourceSourceItemTransformerFactory 
	extends AbstractSourceItemTransformerFactory
{

	private static Item[] PARENT_TO_CHILD = {};
	
	private static Item[] CHILD_TO_PARENT =
		{ Item.SAMPLE, Item.EXTRACT, Item.PHYSICALBIOASSAY, Item.DERIVEDBIOASSAY, Item.RAWBIOASSAY };
	
	
	public ToBioSourceSourceItemTransformerFactory() 
	{
		super(Item.BIOSOURCE, PARENT_TO_CHILD, CHILD_TO_PARENT);
	}
	
	
	@Override
	public SourceItemTransformer create(final Item sourceItemType, final SourceItemTransform transform) 
	{
		List<SourceItemTransformer> chain = new ArrayList<SourceItemTransformer>();
		Item stepBySource = null;
		
		if (transform == SourceItemTransform.CHILD_TO_PARENT)
		{
			// Transforming a list of child items to parent biosources
			// We do step-wise loading from RAWBIOASSAY -> DERIVEDBIOASSAY -> PHYSICALBIOASSAY -> EXTRACT -> SAMPLE -> BIOSOURCE

			// Use utility function to add transformation up to the extract level
			ToExtractSourceItemTransformerFactory.childToParentChain(chain, sourceItemType, Item.BIOSOURCE, false);
			if (chain.size() > 0) 
			{
				// We got some extracts, load parent samples
				chain.add(new ExtractToSampleTransformer());
				stepBySource = Item.SAMPLE;
			}

			if (sourceItemType == Item.SAMPLE || stepBySource == Item.SAMPLE)
			{
				// Load parent samples including source samples
				chain.add(new SampleToParentSampleTransformer(true));
				// Load all parent biosources
				chain.add(new SampleToBioSourceTransformer());
			}

		}

		return chain.size() == 0 ? null : new SourceItemTransformerChain(chain);
	}

}
