/**
	$Id: IndexedCacheKey.java 5748 2011-09-19 10:50:09Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.cache;

import net.sf.basedb.core.BasicItem;

/**
	Cache key implementation that bundles another cache key
	with an index. This type of key is used when moving in
	the reverse direction from a raw bioassay to physical bioassay
	and extracts. The reason is that in this case only
	the extract that belong to the raw bioassay should be loaded. 
	Thus, we also need different cache entries.

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-09-19 12:50:09 +0200 (Mon, 19 Sep 2011) $
*/
public class IndexedCacheKey
{
	private final Object cacheKey;
	private final int index;
	
	/**
		Create a cache key using the id of the BasicItem as the index.
		@param cacheKey The parent cache key
		@param item A BasicItem or null (0 is used as index)
	*/
	public IndexedCacheKey(Object cacheKey, BasicItem item)
	{
		this(cacheKey, item == null ? 0 : item.getId());
	}
	
	public IndexedCacheKey(Object cacheKey, int index)
	{
		this.cacheKey = cacheKey;
		this.index = index;
	}

	/**
		Get the original cache key passed to the constructor.
	*/
	public Object unwrap()
	{
		return cacheKey;
	}
	
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (obj.getClass() != this.getClass()) return false;
		IndexedCacheKey other = (IndexedCacheKey)obj;
		return this.index == other.index && this.cacheKey.equals(other.cacheKey);
	}

	@Override
	public int hashCode()
	{
		return cacheKey.hashCode() * 7 + index;
	}
	
}
