/*
	$Id: TestNumberFormat.java 5776 2011-09-30 11:28:05Z nicklas $

	BioArray Software Environment (BASE) - http://base.thep.lu.se/
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE.

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import java.io.IOException;
import java.io.InputStream;

import net.sf.basedb.util.FileUtil;
import net.sf.basedb.util.charset.CharsetDetector;
import net.sf.basedb.util.charset.CharsetUtil;
import net.sf.basedb.util.charset.SimpleStringDetector;
import net.sf.basedb.util.charset.StringDetector;

public class TestCharsetDetector
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing CharsetDetector");

		test_charset("data/charset-tester-utf-8.txt", "UTF-8", null, null, false);
		test_charset("data/charset-tester-utf-8.txt", "UTF-8", "Namn", "Ålder", false);
		test_charset("data/charset-tester-utf-8.txt", "ISO-8859-1", null, null, false); // No failure but we get incorrect text for Å and ö
		test_charset("data/charset-tester-utf-8.txt", "ISO-8859-1", "Namn", "Ålder", true); // Fails since we can't find Ålder (Å is parsed as Ã…)

		test_charset("data/charset-tester-iso-8859-1.txt", "ISO-8859-1", null, null, false);
		test_charset("data/charset-tester-iso-8859-1.txt", "ISO-8859-1", "Namn", "Ålder", false);
		test_charset("data/charset-tester-iso-8859-1.txt", "UTF-8", "Namn", "Ålder", true); // Fails since file is invalid UTF-8
		
		test_charset("data/charset-tester-iso-8859-1.txt", "ISO-8859-7", null, null, false); // No failure but we get incorrect text for Å and ö
		test_charset("data/charset-tester-iso-8859-1.txt", "ISO-8859-7", "Namn", "Ålder", true); // Fails since Å is Ε (greek)

		// Both files should work with the UTF-8 fallback charset
		test_charset("data/charset-tester-utf-8.txt", "X-UTF-8_with_ISO-8859-1_fallback", "Namn", "Ålder", false);
		test_charset("data/charset-tester-iso-8859-1.txt", "X-UTF-8_with_ISO-8859-1_fallback", "Namn", "Ålder", false);
		
		write("++Testing CharsetDetector "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static void write(String message)
	{
		System.out.println(message);
	}
	
	static void test_charset(String file, String charset, String lookFor, String match, boolean shouldFail)
	{
		InputStream in = null;
		try
		{
			StringDetector lineChecker = null;
			if (lookFor != null && match != null)
			{
				lineChecker = new SimpleStringDetector(lookFor, match);
			}
			CharsetDetector detector = new CharsetDetector(CharsetUtil.getCharset(charset), lineChecker);
			
			in = FileUtil.getInputStream(new java.io.File(file));
			boolean fileIsOk = detector.testIt(in);
			if (!fileIsOk)
			{
				throw detector.getParsingFailure();
			}

			if (shouldFail)
			{
				throw new Exception("Charset (" + charset + ") detection should fail for file: " + file);
			}
			
			write("--Charset (" + charset + ") detection for file '" + file + "' OK");
		}
		catch (IOException ex)
		{
			if (!shouldFail)
			{
				write("--Charset (" + charset + ") detection for file '" + file + "' FAILED");
				ex.printStackTrace();
				ok = false;
			}
			else
			{
				write("--Charset (" + charset + ") detection for file '" + file + "' failed as expected: " + ex.getMessage());
			}
		}
		catch (Throwable t)
		{
			write("--Charset (" + charset + ") detection for file '" + file + "' FAILED");
			t.printStackTrace();
			ok = false;
		}
		finally
		{
			FileUtil.close(in);
		}
	}

}

