<%-- $Id: edit_biowell.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2009 Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------
	@author Martin
	@version 2.10
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.BioPlate"
	import="net.sf.basedb.core.BioPlateType"
	import="net.sf.basedb.core.BioWell"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.MeasuredBioMaterial"
	import="net.sf.basedb.core.Sample"
	import="net.sf.basedb.core.Extract"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.WellCoordinateFormatter"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.BIOWELL;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Edit "+itemType);
try
{
	String title = null;
	BioWell bioWell = BioWell.getById(dc, itemId);
	BioPlate bioPlate = bioWell.getPlate();
	BioPlateType bioPlateType = bioPlate.getBioPlateType();
	Item bioMaterialType = bioPlateType.getBioMaterialType();
	ItemSubtype bioMaterialSubType = bioPlateType.getItemSubtype();
	
	bioWell.checkPermission(Permission.USE);
	WellCoordinateFormatter rowFormatter = new WellCoordinateFormatter(true);
	WellCoordinateFormatter columnFormatter = new WellCoordinateFormatter(false);
	
	title = "Edit biowell -- " + rowFormatter.format(bioWell.getRow()) + columnFormatter.format(bioWell.getColumn()) + " on " + HTML.encodeTags(bioPlate.getName());

	boolean readCurrentBioMaterial = true;
	MeasuredBioMaterial currentBioMaterial = null;
	try
	{
		currentBioMaterial = bioWell.getBioMaterial();
	}
	catch (PermissionDeniedException ex)
	{
		readCurrentBioMaterial = false;
	}
	boolean canAddBioMaterial = bioWell.canAddBioMaterial();

	cc.setObject("item", bioWell);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), bioWell);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="~biowells.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help helpid="biowell.edit" /></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="biowell">
		<input type="hidden" name="cmd" value="UpdateItem">

		<div class="content bottomborder">

			<table class="fullform input100">
			<tr>
				<th>Bioplate</th>
				<td><%=HTML.encodeTags(bioPlate.getName())%></td>
			</tr>
			<tr>
				<th>Well location</th>
				<td><%=rowFormatter.format(bioWell.getRow())%><%=columnFormatter.format(bioWell.getColumn())%></td>
			</tr>
			<tr>
				<th>Biomaterial type</th>
				<td>					
					<select name="biomaterial_type" <%=bioMaterialType != null ? "disabled": ""%>>
						<%
						if (!readCurrentBioMaterial)
						{
							%>
							<option value="-1">- denied -
							<%
						}
						else
						{
							Item currentBmType = currentBioMaterial == null ? null : currentBioMaterial.getType();
							String subtype = bioMaterialSubType != null ? " ("+HTML.encodeTags(bioMaterialSubType.getName()) + ")" : "";
							%>
							<option value="0">- none -
							<option value="<%=Item.SAMPLE.name()%>" 
								<%=currentBmType == Item.SAMPLE || bioMaterialType == Item.SAMPLE ? "selected" : ""%>>Sample<%=subtype %>
							<option value="<%=Item.EXTRACT.name()%>" 
								<%=currentBmType == Item.EXTRACT || bioMaterialType == Item.EXTRACT ? "selected" : ""%>>Extract<%=subtype %>
							<%
						}
						%>
					</select>
				</td>
			</tr>
			<tr>
				<th>Biomaterial</th>
				<td>
					<base:select 
						id="biomaterial_id"
						clazz="selectionlist"
						required="false"
						current="<%=currentBioMaterial%>"
						denied="<%=!readCurrentBioMaterial%>"
						recent="<%=null%>"
						newitem="<%=false%>"
						data-biomaterial-subtype="<%=bioMaterialSubType == null ? "" : bioMaterialSubType.getId() %>"
					/>
				</td>
			</tr>
			<%
			if (!canAddBioMaterial && currentBioMaterial != null)
			{
				%>
				<tr>
					<th></th>
					<td>
						<div class="messagecontainer note">
							New biomaterial can't be added to this well if 
							'<%=HTML.encodeTags(currentBioMaterial.getName())%>' is removed.
						</div>
					</td>
				</tr>
				<%
			}
			%>
			<tr class="dynamic">
				<th></th>
				<td></td>
			</tr>
			</table>
		</div>
		</form>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
