<%-- $Id: save_preset.jsp 6607 2014-11-19 14:52:20Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.SyncFilter.SourceItemTransform"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.listable.SourceItemTransformerFactory"
	import="net.sf.basedb.util.listable.ListableUtil"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final Item itemType = Item.valueOf(request.getParameter("item_type"));

SourceItemTransformerFactory factory = ListableUtil.getTransformerFactory(itemType);
List<Item> allowedParentItems = factory.getSupportedSourceItems(SourceItemTransform.PARENT_TO_CHILD);
List<Item> allowedChildItems = factory.getSupportedSourceItems(SourceItemTransform.CHILD_TO_PARENT);
%>
<base:page type="popup" title="Add parent or child item column">
<base:head scripts="~add_relateditem_column.js">
<style>
th
{
	min-width: 10em;
}
select
{
	width: calc(100% - 1em);
	min-width: 15em;
	padding: 2px 4px;
}

.columnstable
{
	width: 100%;
	position: absolute;
	border-collapse: separate;
}

.columnstable thead
{
	position: sticky;
	top: 0;
}

.columnstable tr
{
	vertical-align: top;
}

.columnstable tr.bottomborder th
{
	border-bottom-width: 1px;
}

.columnstable tr.topborder th
{
	border-top-width: 1px;
}

.columnstable th
{
	text-align: left;
	padding: 2px 4px;
}

.columnstable td
{
	text-align: left;
	padding: 4px 1px;
}

.columnstable td > div
{
	margin-bottom: 4px;
	white-space: nowrap;
}

#added-column-msg
{
	position: absolute;
	bottom: 1em;
	left: 0;
	right: 0;
	display: table;
	margin-left: auto;
	margin-right: auto;
}

.parentitem::before
{
	content: url('../../images/parent-item.png');
	margin: 0 2px;
	vertical-align: -2px;
}
.childitem::before
{
	content: url('../../images/child-item.png');
	margin: 0 2px;
	vertical-align: -2px;
}

.columnsFrom
{
	font-weight: bold;
}

.columnsFrom > span
{}
</style>
</base:head>
<base:body>
	<h1>Add parent or child item column <base:help helpid="columns.configure.add_relateditem_column" /></h1>

	<form name="relatedItems" method="post">
	<input type="hidden" name="ID" value="<%=ID%>">
	<input type="hidden" name="item_type" value="<%=itemType.name()%>">
	
	<div class="content">
		<div class="absolutefull" >
		<table class="fullform input100 bottomborder">
		<tr>
			<th>Parent/child</th>
			<td>
				<select name="targetItemType" id="targetItemType" class="required">
					<option value="">- select -
					<%
					for (Item parentType : allowedParentItems)
					{
						%>
						<option value="<%=parentType.name()%>" data-direction="PARENT">Parent: <%=parentType.toString()%>
						<%
					}
					for (Item childType : allowedChildItems)
					{
						%>
						<option value="<%=childType.name()%>" data-direction="CHILD">Child: <%=childType.toString()%>
						<%
					}
					%>
				</select>
			</td>
			<td style="white-space: nowrap;">with link to</td>
			<td>
				<select name="childItemType" id="childItemType" disabled>
					<option value="">- optional -
				</select>
			</td>
			<td>
			</td>
		</tr>
		<tr>
			<th>Subtype</th>
			<td>
				<select name="targetSubtype" id="targetSubtype" class="required" disabled>
					<option value="">- select -
				</select>
			</td>
			<td>subtype</td>
			<td>
				<select name="childSubtype" id="childSubtype" disabled>
					<option value="">- select -
				</select>
			</td>
		</tr>
		<tr>
			<th class="subprompt"></th>
			<td>
				<label><input type="checkbox" id="showAllAnnotationTypes" 
					name="showAllAnnotationTypes">Show annotations for all subtypes</label>
			</td>
			<td></td>
			<td>
				<label title="Normally, child items that was passed when going up to the parent are ignored when going down. Enable this option to include all child items."
					><input type="checkbox" id="allowDoublingBack" name="allowDoublingBack" disabled
					>Allow doubling back</label>
			</td>
		</tr>
		<tr>
			<th>Extra filter</th>
			<td colspan="3">
				<select name="extraFilter" id="extraFilter" disabled 
					style="width: auto; max-width: 20em;">
					<option value="">- optional -
				</select>
				=
				<select name="targetAnnotationValue" id="targetAnnotationValue" disabled 
					style="width: auto;">
					<option value="">- select -
				</select>
			</td>
		</tr>
		<tr class="dynamic">
			<th class="subprompt" style="white-space: normal; text-align: left; padding-left: 1em;">
			An additional filter can be defined for enumerated annotations or item lists.
			</th>
			<td colspan="3" class="columnsFrom" style="padding-top: 2px;">
				<span id="targetPath"></span><span id="childPath" class="childitem" style="display: none;"></span>
			</td>
		</tr>
		</table>
		</div>
		
		<div class="absolutefull" style="top: 9em; left: 10em;">		
			<table id="columnstable" class="columnstable" style="width: 100%;">
			<thead class="">
				<tr class="bg-filled-100 topborder bottomborder">
					<th style="width: 33%;">Columns</th>
					<th style="width: 33%;">Annotations</th>
					<th style="width: 34%;">Extensions</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td id="columns"></td>
					<td id="annotations"></td>
					<td id="extensions"></td>
				</tr>
			</tbody>
			</table>
		</div>
		
		<div id="added-column-msg" class="messagecontainer note" style="display:none;">message</div>

	</div>
	</form>

	<base:buttongroup subclass="dialogbuttons">
		<base:button id="btnAdd" title="Add" />
		<base:button id="close" title="Close" />
	</base:buttongroup>

</base:body>
</base:page>


