<%-- $Id: list_jobs.jsp 8189 2023-12-20 13:17:19Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Job"
	import="net.sf.basedb.core.JobAgent"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Nameable"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Restrictions"
	import="net.sf.basedb.core.query.Expressions"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.util.ShareableUtil"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.ModeInfo"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnAction"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Iterator"
	import="java.util.List"
	import="java.util.Map"
	import="java.util.Date"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.JOB;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.LIST);
	
	private static final Enumeration<String, String> status = new Enumeration<String, String>();
	private static final Enumeration<String, String> pluginTypes = new Enumeration<String, String>();
	private static final Enumeration<String, String> execTime = new Enumeration<String, String>();
	static
	{
		for (Job.Status s : Job.Status.values())
		{
			status.add(Integer.toString(s.getValue()), HTML.encodeTags(s.toString()));
		}
		for (Plugin.MainType pt : Plugin.MainType.values())
		{
			pluginTypes.add(Integer.toString(pt.getValue()), HTML.encodeTags(pt.toString()));
		}
		for (Job.ExecutionTime et : Job.ExecutionTime.values())
		{
			execTime.add(Integer.toString(et.getValue()), HTML.encodeTags(et.toString()));
		}
	}
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, Permission.DENIED, itemType);
final String ID = sc.getId();
final boolean createPermission = sc.hasPermission(Permission.CREATE, itemType);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final Date now = new Date();
final ModeInfo mode = ModeInfo.get(request.getParameter("mode"));
final String callback = request.getParameter("callback");
final String title = mode.generateTitle("job", "jobs");
final DbControl dc = sc.newDbControl(":List "+itemType);
ItemResultIterator<Job> jobs = null;
try
{
	
	// Get all job agents
	final ItemQuery<JobAgent> agentQuery = JobAgent.getQuery();
	agentQuery.include(Include.ALL);
	agentQuery.order(Orders.asc(Hql.property("name")));
	agentQuery.setCacheResult(true);
	Enumeration<String, String> agents = new Enumeration<String, String>();
	for (JobAgent a : agentQuery.list(dc))
	{
		agents.add(Integer.toString(a.getId()), a.getName());
	}
	// Load subtypes
	final ItemQuery<ItemSubtype> typeQuery = ItemSubtype.getQuery(itemType);
	typeQuery.order(Orders.asc(Hql.property("name")));
	typeQuery.setCacheResult(true);
	
	// Load projects
	final ItemQuery<Project> projectQuery = Project.getQuery();
	projectQuery.setIncludes(cc.getInclude());
	projectQuery.order(Orders.asc(Hql.property("name")));
	projectQuery.setCacheResult(true);

	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, null);
	try
	{
		final ItemQuery<Job> query = Base.getConfiguredQuery(dc, cc, jspContext, true, Job.getQuery(), mode);
		jobs = query.iterate(dc);
	}
	catch (Throwable t)
	{
		cc.setMessage(t.getMessage());
		t.printStackTrace();
	}
	int numListed = 0;
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	ExtensionsInvoker<ListColumnAction<Job,?>> columnsInvoker = ListColumnUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title==null ? "Jobs" : title%>" type="<%=mode.getPageType()%>" id="list-page">
	<base:head scripts="table.js,~jobs.js" styles="table.css,toolbar.css,progressbar.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	
	<base:body>
		<h1><%=title==null ? "Jobs" : title%></h1>
		<div class="content">
		<tbl:table 
			id="jobs" 
			columns="<%=cc.getSetting("columns")%>"
			sortby="<%=cc.getSortProperty()%>" 
			direction="<%=cc.getSortDirection()%>"
			action="index.jsp"
			sc="<%=sc%>"
			item="<%=itemType%>"
			filterrows="<%=cc.getFilterRows()%>"
			subclass="fulltable"
			stickyheaders="<%=cc.getSetting("columns.sticky", "name")%>"
			>
			<tbl:hidden 
				name="mode" 
				value="<%=mode.getName()%>" 
			/>
			<tbl:hidden 
				name="callback" 
				value="<%=callback%>" 
				skip="<%=callback == null%>" 
			/>
			<tbl:columndef 
				id="name"
				property="name"
				datatype="string"
				title="Name"
				sortable="true" 
				filterable="true"
				exportable="true"
				show="always" 
			/>
			<tbl:columndef 
				id="id"
				clazz="uniquecol"
				property="id"
				datatype="int"
				title="ID"
				sortable="true"
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="externalId"
				property="externalId"
				datatype="string"
				title="External ID"
				sortable="true"
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="itemSubtype"
				property="itemSubtype"
				sortproperty="itemSubtype.name"
				exportproperty="itemSubtype.name:string"
				datatype="int"
				enumeration="<%=Enumeration.fromItems(typeQuery.list(dc), "-none-")%>"
				title="Subtype"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="owner"
				property="owner.name"
				datatype="string"
				title="Owner"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="priority"
				property="priority"
				datatype="int"
				title="Priority"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="status"
				property="status"
				datatype="int"
				enumeration="<%=status%>"
				title="Status"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="statusMessage"
				property="statusMessage"
				datatype="string"
				title="Status message"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="dryRun"
				property="dryRun"
				datatype="boolean"
				title="Dry run"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="stackTrace"
				property="stackTrace"
				datatype="string"
				title="Stack trace"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="server"
				property="server"
				datatype="string"
				title="Server"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="node"
				property="node"
				datatype="string"
				title="Node"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="jobagent"
				property="jobAgentId"
				datatype="int"
				title="Job agent"
				filterable="true"
				enumeration="<%=agents%>"
			/>
			<tbl:columndef 
				id="percentComplete"
				property="percentComplete"
				datatype="int"
				title="Percent complete"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="estimatedExecutionTime"
				property="estimatedExecutionTime"
				datatype="int"
				enumeration="<%=execTime%>"
				title="Estimated time"
				tooltip="An estimation of the execution time of the plugin"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef
				id="runningTime"
				title="Running time"
			/>
			<tbl:columndef 
				id="created" 
				property="created"
				datatype="timestamp" 
				title="Created" 
				sortable="true" 
				filterable="true" 
				exportable="true"
				formatter="<%=dateTimeFormatter%>"
			/>
			<tbl:columndef 
				id="scheduled" 
				property="scheduled"
				datatype="timestamp" 
				title="Scheduled" 
				sortable="true" 
				filterable="true" 
				exportable="true"
				formatter="<%=dateTimeFormatter%>"
			/>
			<tbl:columndef 
				id="started" 
				property="started"
				datatype="timestamp" 
				title="Started" 
				sortable="true" 
				filterable="true" 
				exportable="true"
				formatter="<%=dateTimeFormatter%>"
			/>
			<tbl:columndef 
				id="ended" 
				property="ended"
				datatype="timestamp" 
				title="Ended" 
				sortable="true" 
				filterable="true" 
				exportable="true"
				formatter="<%=dateTimeFormatter%>"
			/>
			<tbl:columndef
				id="pluginType"
				property="pluginDefinition.mainType"
				datatype="int"
				title="Type"
				enumeration="<%=pluginTypes%>"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="activeProject"
				property="activeProjectId"
				datatype="int"
				title="Active project"
				enumeration="<%=Enumeration.fromItems(projectQuery.list(dc), "-none-", "0")%>"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="experiment"
				property="experiment.name"
				datatype="string"
				title="Experiment"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="plugin"
				property="pluginDefinition.name"
				datatype="string"
				title="Plugin"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="pluginVersion"
				property="pluginVersion"
				datatype="string"
				title="Plugin version"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="configuration"
				property="pluginConfiguration.name"
				datatype="string"
				title="Configuration"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="description"
				property="description"
				datatype="string"
				title="Description" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef
				id="permission"
				title="Permission"
			/>
			<tbl:columndef
				id="sharedTo"
				title="Shared to"
				filterable="true"
				filterproperty="!sharedTo.name"
				datatype="string"
			/>
			<tbl:columndef 
				id="xt-columns" 
				extensions="<%=columnsInvoker%>" 
				jspcontext="<%=jspContext%>" 
			/>
			<div class="panelgroup bg-filled-50 bottomborder">
				<tbl:toolbar
					subclass="bottomborder"
					visible="<%=mode.hasToolbar()%>"
					>
					<tbl:button 
						id="btnDeleteItems"
						image="delete.png"
						title="Delete" 
						tooltip="Delete the selected items" 
					/>
					<tbl:button 
						id="btnRestoreItems"
						image="restore.png"
						title="Restore" 
						tooltip="Restore the selected (deleted) items"
					/>
					<tbl:button 
						id="btnAbort"
						image="abort.png"
						title="Abort&hellip;" 
						tooltip="Abort the selected items"
					/>
					<tbl:button 
						id="btnPause"
						image="pause.png"
						title="Pause&hellip;" 
						tooltip="Pause the selected items (if they supports it)"
					/>
					<tbl:button 
						id="btnShareItems"
						image="share.png"
						title="Share&hellip;" 
						tooltip="Share the selected items"
					/>
					<tbl:button 
						id="btnSetOwner"
						image="take_ownership.png"
						title="Set owner&hellip;"
						tooltip="Change owner of the selected items"
					/>
					<tbl:button 
						id="btnColumns"
						image="columns.png" 
						title="Columns&hellip;" 
						tooltip="Show, hide and re-order columns" 
					/>
					<tbl:button 
						id="btnImport"
						data-plugin-type="IMPORT"
						image="import.png" 
						title="Import&hellip;" 
						tooltip="Import data" 
						visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
					/>
					<tbl:button 
						id="btnExport"
						data-plugin-type="EXPORT"
						image="export.png" 
						title="Export&hellip;" 
						tooltip="Export data" 
						visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
					/>
					<tbl:button 
						id="btnRunPlugin"
						data-plugin-type="OTHER"
						image="runplugin.png" 
						title="Run plugin&hellip;" 
						tooltip="Run a plugin" 
						visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
					/>
					<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
						wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
				</tbl:toolbar>
				<tbl:panel>
					<tbl:presetselector />
					<tbl:navigator
						page="<%=cc.getPage()%>" 
						rowsperpage="<%=cc.getRowsPerPage()%>" 
						totalrows="<%=jobs == null ? 0 : jobs.getTotalCount()%>" 
						visible="<%=mode.hasNavigator()%>"
					/>
				</tbl:panel>
			</div>
			<tbl:data>
				<tbl:headers>
					<tbl:headerrow>
						<tbl:header clazz="row-index bg-filled-100" />
						<tbl:columnheaders />
					</tbl:headerrow>
					<%
					int numFilters = cc.getNumPropertyFilters();
					int numRows = cc.getFilterRows();
					for (int filterNo = 0; filterNo < numRows; filterNo++)
					{
						boolean lastRow = filterNo == numRows-1;
						%>
						<tbl:headerrow>
							<tbl:header subclass="row-index bg-filled-100">
								<div class="index-<%=mode.getName()%>">
									<div class="index"></div>
									<div class="check">
										<base:icon 
											subclass="link table-check"
											image="check_uncheck.png" 
											tooltip="Toggle all (use CTRL, ALT or SHIFT to check/uncheck)" 
											visible="<%=lastRow && mode.hasCheck()%>"
										/>
									</div>
									<div class="icons">
										<base:icon
											subclass="link table-filter-row-action"
											image="add.png"
											tooltip="Add extra filter row"
											visible="<%=lastRow%>"
										/><base:icon
											subclass="link table-filter-row-action"
											image="remove.png"
											tooltip="Remove this filter row"
											visible="<%=numRows > 1 || numFilters > 0 %>"
											data-remove-row="<%=filterNo%>"
										/>
									</div>
								</div>
							</tbl:header>
							<tbl:propertyfilter row="<%=filterNo%>" />
						</tbl:headerrow>
						<%
					}
					%>
					<tbl:columnsubtitles />
				</tbl:headers>
				<tbl:rows>
					<%
					if (cc.getMessage() != null)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer error"><%=cc.getMessage()%></div>
						</tbl:panel>
						<%
						cc.setMessage(null);
					}
					int index = cc.getPage()*cc.getRowsPerPage();
					int selectedItemId = cc.getId();
					if (jobs != null)
					{
						String tooltip = mode.isSelectionMode() ?
							"Select this item" : "View this item";
						while (jobs.hasNext())
						{
							Job item = jobs.next();
							int itemId = item.getId();
							String name = HTML.encodeTags(item.getName());
							
							boolean deletePermission = item.hasPermission(Permission.DELETE);
							boolean sharePermission = item.hasPermission(Permission.SET_PERMISSION);
							index++;
							numListed++;
							PluginDefinition plugin = null;
							boolean readPlugin = true;
							try
							{
								plugin = item.getPluginDefinition();
							}
							catch (PermissionDeniedException ex)
							{
								readPlugin = false;
							}
							JobAgent agent = null;
							boolean readAgent = true;
							try
							{
								agent = item.getJobAgent();
							}
							catch (PermissionDeniedException ex)
							{
								readAgent = false;
							}
							%>
							<tbl:row>
								<tbl:header clazz="row-index bg-filled-100">
									<div class="index-<%=mode.getName()%>">
										<div class="index <%=index>999?"index-smaller":""%>"><%=index%></div>
										<div class="check">
											<base:input
												type="checkbox" 
												name="<%=itemId%>" 
												value="<%=itemId%>" 
												title="<%=name%>" 
												checked="<%=cc.getSelected().contains(itemId)%>"
												visible="<%=mode.hasCheck()%>"
											/>
											<base:input 
												type="radio" 
												name="item_id" 
												value="<%=itemId%>" 
												title="<%=name%>" 
												checked="<%=selectedItemId == itemId%>"
												visible="<%=mode.hasRadio()%>"
											/>
										</div>
										<div class="icons">
											<base:icon 
												image="deleted.png"
												id="<%="delete."+itemId %>"
												subclass="<%=deletePermission ? "table-delete-item" : "disabled" %>"
												data-item-id="<%=itemId%>"
												tooltip="This item has been scheduled for deletion" 
												visible="<%=item.isRemoved()%>"
											/><base:icon 
												image="shared.png" 
												id="<%="share."+itemId %>"
												subclass="<%=sharePermission ? "table-share-item" : "disabled" %>"
												data-item-id="<%=itemId%>"
												tooltip="This item is shared to other users, groups and/or projects" 
												visible="<%=item.isShared()%>"
											/>
										</div>
									</div>
								</tbl:header>
								<tbl:cell column="name"><div 
									class="link table-item"
									data-item-id="<%=itemId%>"
									data-no-edit="1"
									tabindex="0"
									title="<%=tooltip%>"><%=name%></div></tbl:cell>
								<tbl:cell column="id"><%=item.getId()%></tbl:cell>
								<tbl:cell column="externalId"><%=HTML.encodeTags(item.getExternalId())%></tbl:cell>
								<tbl:cell column="itemSubtype"
									><base:propertyvalue 
										item="<%=item%>" 
										property="itemSubtype"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="owner"
									><base:propertyvalue 
										item="<%=item%>" 
										property="owner"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="priority"><%=item.getPriority()%></tbl:cell>
								<tbl:cell column="status"><%=item.getStatus()+(item.isDryRun()?" (dry-run)":"")%></tbl:cell>
								<tbl:cell column="statusMessage"><%=HTML.encodeTags(item.getStatusMessage())%></tbl:cell>
								<tbl:cell column="dryRun"><%=item.isDryRun()%></tbl:cell>
								<tbl:cell column="stackTrace"><%=HTML.encodeTags(item.getStackTrace())%></tbl:cell>
								<tbl:cell column="server"><%=HTML.encodeTags(item.getServer())%></tbl:cell>
								<tbl:cell column="node"><%=HTML.encodeTags(item.getNode())%></tbl:cell>
								<tbl:cell column="jobagent"><%=Base.getLinkedName(ID, agent, !readAgent, true)%></tbl:cell>
								<tbl:cell column="estimatedExecutionTime"><%=item.getEstimatedExecutionTime()%></tbl:cell>
								<tbl:cell column="percentComplete">
									<table class="progressbar <%=item.getStatus() == Job.Status.ERROR ? "failed" : ""%> <%=item.isDryRun()?"dry-run":""%>">
									<tr>
									<td>
										<table class="bar" style="width: 100px;">
										<tr>
											<%
											int percent = item.getPercentComplete();
											if (percent > 0) 
											{
												%>
												<td style="width: <%=percent%>%;" class="percentDone">&nbsp;</td>
												<% 
											}
											if (percent == -1)
											{
												%>
												<td style="width: 100%;" class="percentUnknown">unknown</td>
												<%
											}
											else if (percent < 100) 
											{ 
												%>
												<td style="width: <%=100-percent%>%;" class="percentRemain">&nbsp;</td>
												<%
											}
											%>
										</tr>
										</table>
									</td>
									<%if (percent != -1) { %>
										<td class="percentText"><%=percent%>%</td>
									<%} %>
									</tr>
									</table>
								</tbl:cell>
								<tbl:cell column="created" value="<%=item.getCreated()%>" />
								<tbl:cell column="scheduled" value="<%=item.getScheduled()%>" />
								<tbl:cell column="started" value="<%=item.getStarted()%>" />
								<tbl:cell column="ended" value="<%=item.getEnded()%>" />
								<tbl:cell column="runningTime">
									<%
									Date started = item.getStarted();
									if (started != null)
									{
										Date ended = item.getEnded();
										if (ended == null) ended = now;
										long runningTime = ended.getTime() - started.getTime();
										%>
										<%=Values.formatTime(runningTime / 1000)%>
										<%
									}
									%>
								</tbl:cell>
								<tbl:cell column="description"><%=HTML.encodeTags(item.getDescription())%></tbl:cell>
								<tbl:cell column="pluginType">
									<%
									if (!readPlugin)
									{
										%>
										<i>- denied -</i>
										<%
									}
									else if (plugin == null)
									{
										%>
										<i>- none -</i>
										<%
									}
									else
									{
										%>
										<%=plugin.getMainType()%>
										<%
									}
									%>
								</tbl:cell>
								<tbl:cell column="activeProject">
									<%
									if (item.getActiveProjectId() == 0)
									{
										%>
										<i>- none -</i>
										<%
									}
									else
									{
										try
										{
											Project p = Project.getById(dc, item.getActiveProjectId());
											%>
											<%=HTML.encodeTags(p.getName())%>
											<%
										}
										catch (RuntimeException ex)
										{
											%>
											<i>- denied -</i>
											<%
										}
									}
									%>
								</tbl:cell>
								<tbl:cell column="experiment"
									><base:propertyvalue 
										item="<%=item%>" 
										property="experiment"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="plugin">
									<%
									if (!readPlugin)
									{
										%>
										<i>- denied -</i>
										<%
									}
									else if (plugin == null)
									{
										%>
										<i>- none -</i>
										<%
									}
									else
									{
										%>
										<%=HTML.encodeTags(plugin.getName())%>
										<%
									}
									%>
								</tbl:cell>
								<tbl:cell column="pluginVersion"><%=HTML.encodeTags(item.getPluginVersion())%></tbl:cell>
								<tbl:cell column="configuration"
									><base:propertyvalue 
										item="<%=item%>" 
										property="pluginConfiguration"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="permission"><%=PermissionUtil.getShortPermissions(item)%></tbl:cell>
								<tbl:cell column="sharedTo">
									<%
									Iterator<Nameable> sharees = ShareableUtil.getSharedTo(dc, item).iterator();
									while(sharees.hasNext())
									{
										Nameable n = sharees.next();
										if (mode.hasPropertyLink())
										{
											out.write(Base.getLinkedName(ID, n, false, mode.hasEditLink()));
										}
										else
										{
											out.write(HTML.encodeTags(n.getName()));
										}
										out.write(sharees.hasNext() ? ", " : "");
									}
									%>
								</tbl:cell>
								<tbl:xt-cells dc="<%=dc%>" item="<%=item%>">
									<tbl:cell column="xt-columns" />
								</tbl:xt-cells>
							</tbl:row>
							<%
							}
						}
					if (numListed == 0)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer note">
							<%=jobs == null || jobs.getTotalCount() == 0 ? "No jobs were found" : "No jobs on this page. Please select another page!" %>
							</div>
						</tbl:panel>
						<%
					}
					%>
				</tbl:rows>
			</tbl:data>
		</tbl:table>
		</div>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnOk" title="Ok" visible="<%=mode.hasOkButton()%>" />
			<base:button id="close" title="Cancel" visible="<%=mode.hasCancelButton()%>" />
			<base:button id="close" title="Close" visible="<%=mode.hasCloseButton()%>" />
		</base:buttongroup>
		
	</base:body>
	</base:page>
	<%
}
finally
{
	if (jobs != null) jobs.close();
	if (dc != null) dc.close();
}
%>
